@@ -58,6 +58,7 @@ class CONTAINER_IMAGES:
     HACKER_IMAGES = ["csle_hacker_kali_1"]
     CLIENT_IMAGES = ["csle_client_1"]
     CADVISOR = "cadvisor"
+    PGADMIN = "pgadmin"
     GRAFANA = "grafana"
 
 
@@ -870,13 +871,21 @@ class COMMANDS:
     MANAGEMENT_SYSTEM_PORT = 7777
     START_GRAFANA = f"docker run -d -p {GRAFANA_PORT}:{GRAFANA_PORT} --name grafana grafana/grafana"
     CADVISOR_PORT = 8080
+    PGADMIN_PORT = 7778
     START_CADVISOR = "docker run  -dt --volume=/:/rootfs:ro   --volume=/var/run:/var/run:ro   " \
                      "--volume=/sys:/sys:ro   " \
                      "--volume=/var/lib/docker/:/var/lib/docker:ro   --volume=/dev/disk/:/dev/disk:ro   " \
                      f"--publish={CADVISOR_PORT}:{CADVISOR_PORT}  --name=cadvisor  " \
                      "google/cadvisor:latest"
+    PGADMIN_USERNAME = "csle@csle.com"
+    PGADMIN_PW = "cslePassword"
+    GRAFANA_USERNAME = "admin"
+    GRAFANA_PW = "admin"
+    START_PGADMIN = f"docker run -p 7778:80 -e 'PGADMIN_DEFAULT_EMAIL={PGADMIN_USERNAME}' -e " \
+                    f"'PGADMIN_DEFAULT_PASSWORD={PGADMIN_PW}' -d --name=pgadmin dpage/pgadmin4"
     CONTAINER_LOGS = "docker logs {}"
     CADVISOR_LOGS = "docker logs cadvisor"
+    PGADMIN_LOGS = "docker logs pgadmin"
     GRAFANA_LOGS = "docker logs grafana"
     NODE_EXPORTER_PID_FILE = "/var/log/csle/node_exporter.pid"
     MANAGEMENT_SYSTEM_PID_FILE = "/var/log/csle/management_system.pid"
@@ -893,6 +902,15 @@ class COMMANDS:
     START_SYSTEM_IDENTIFICATION_JOB = "nohup csle systemidentificationjob {} &"
     DOCKER_EXEC_COMMAND = "docker exec"
     PING = "ping"
+    NGINX_STATUS = "service nginx status"
+    POSTGRESQL_STATUS = "service postgresql status"
+    DOCKER_ENGINE_STATUS = "service docker status"
+    POSTGRESQL_START = "sudo service postgresql start"
+    POSTGRESQL_STOP = "sudo service postgresql stop"
+    NGINX_START = "sudo service nginx start"
+    NGINX_STOP = "sudo service nginx stop"
+    DOCKER_ENGINE_START = "sudo service docker start"
+    DOCKER_ENGINE_STOP = "sudo service docker stop"
 
 
 class OVS:
@@ -1183,6 +1201,15 @@ class AGENT:
     PW = "agent"
 
 
+class CITUS:
+    COORDINATOR_PORT = 5432
+
+
+class CLUSTER_CONFIG:
+    LEADER = False
+    IP = "127.0.0.1"
+
+
 class CSLE_ADMIN:
     """
     Constants related to the default csle admin account.
@@ -1509,6 +1536,7 @@ class METADATA_STORE:
     EMULATION_EXECUTIONS_TABLE = "emulation_executions"
     EMPIRICAL_SYSTEM_MODELS_TABLE = "empirical_system_models"
     GP_SYSTEM_MODELS_TABLE = "gp_system_models"
+    CONFIG_TABLE = "config"
     MANAGEMENT_USERS_TABLE = "management_users"
     SESSION_TOKENS_TABLE = "session_tokens"
     TRACES_DATASETS_TABLE = "traces_datasets"
