@@ -1,7 +1,6 @@
 from typing import Dict, Any, Union
 from csle_common.dao.emulation_config.cluster_config import ClusterConfig
 import csle_common.constants.constants as constants
-from csle_common.logging.log import Logger
 import os
 import io
 import json
@@ -22,12 +21,14 @@ class Config:
                  metastore_user: str, metastore_password: str, metastore_database_name: str, metastore_ip: str,
                  node_exporter_port: int, grafana_port: int,
                  management_system_port: int, cadvisor_port: int, prometheus_port: int, node_exporter_pid_file: str,
+                 pgadmin_port: int,
                  management_system_pid_file: str, docker_stats_manager_log_file: str, docker_stats_manager_log_dir: str,
                  docker_stats_manager_port: int, docker_stats_manager_max_workers: int,
                  docker_stats_manager_outfile: str, docker_stats_manager_pidfile: str, prometheus_pid_file: str,
                  prometheus_log_file: str, prometheus_config_file: str, default_log_dir: str,
                  cluster_config: ClusterConfig, node_exporter_log_file: str,
-                 allow_registration: bool, allow_host_shell: bool):
+                 allow_registration: bool, allow_host_shell: bool, grafana_username: str, grafana_password: str,
+                 pgadmin_username: str, pgadmin_password: str):
         """
         Initializes the DTO
 
@@ -57,6 +58,7 @@ class Config:
         :param management_system_port: the default port to run the management system
         :param cadvisor_port: the default port to run c_advisor
         :param prometheus_port: the default port to run prometheus
+        :param pgadmin_port: the default port to run pgadmin
         :param node_exporter_pid_file: the default port to run node_exporter
         :param management_system_pid_file: the file to save the PID of the management system
         :param docker_stats_manager_log_file: the file to save the logs of docker statsmanager
@@ -73,6 +75,10 @@ class Config:
         :param node_exporter_log_file: the file to save the logs of the node_exporter
         :param allow_registration: boolean flag indicating whether user registration should be allowed
         :param allow_host_shell: boolean flag indicating whether host-terminal emulation should be enabled.
+        :param grafana_username: default grafana username
+        :param grafana_password: default grafana password
+        :param pgadmin_username: default pgadmin username
+        :param pgadmin_password: default pgadmin password
         """
         self.management_admin_username_default = management_admin_username_default
         self.management_admin_password_default = management_admin_password_default
@@ -99,6 +105,7 @@ class Config:
         self.management_system_port = management_system_port
         self.cadvisor_port = cadvisor_port
         self.prometheus_port = prometheus_port
+        self.pgadmin_port = pgadmin_port
         self.node_exporter_pid_file = node_exporter_pid_file
         self.management_system_pid_file = management_system_pid_file
         self.docker_stats_manager_log_file = docker_stats_manager_log_file
@@ -115,6 +122,11 @@ class Config:
         self.node_exporter_log_file = node_exporter_log_file
         self.allow_registration = allow_registration
         self.allow_host_shell = allow_host_shell
+        self.grafana_username = grafana_username
+        self.grafana_password = grafana_password
+        self.pgadmin_username = pgadmin_username
+        self.pgadmin_password = pgadmin_password
+        self.id = -1
 
     def to_dict(self) -> Dict[str, Any]:
         """
@@ -145,6 +157,7 @@ class Config:
         d["grafana_port"] = self.grafana_port
         d["management_system_port"] = self.management_system_port
         d["cadvisor_port"] = self.cadvisor_port
+        d["pgadmin_port"] = self.pgadmin_port
         d["prometheus_port"] = self.prometheus_port
         d["node_exporter_pid_file"] = self.node_exporter_pid_file
         d["management_system_pid_file"] = self.management_system_pid_file
@@ -162,6 +175,11 @@ class Config:
         d["node_exporter_log_file"] = self.node_exporter_log_file
         d["allow_registration"] = self.allow_registration
         d["allow_host_shell"] = self.allow_host_shell
+        d["grafana_username"] = self.grafana_username
+        d["grafana_password"] = self.grafana_password
+        d["pgadmin_username"] = self.pgadmin_username
+        d["pgadmin_password"] = self.pgadmin_password
+        d["id"] = self.id
         return d
 
     def to_param_dict(self) -> Dict[str, Any]:
@@ -450,6 +468,41 @@ class Config:
                 "value": self.allow_host_shell
             }
         )
+        d["parameters"].append(
+            {
+                "id": 42,
+                "param": "pgadmin_port",
+                "value": self.pgadmin_port
+            }
+        )
+        d["parameters"].append(
+            {
+                "id": 43,
+                "param": "pgadmin_username",
+                "value": self.pgadmin_username
+            }
+        )
+        d["parameters"].append(
+            {
+                "id": 44,
+                "param": "pgadmin_password",
+                "value": self.pgadmin_password
+            }
+        )
+        d["parameters"].append(
+            {
+                "id": 45,
+                "param": "grafana_username",
+                "value": self.grafana_username
+            }
+        )
+        d["parameters"].append(
+            {
+                "id": 46,
+                "param": "grafana_password",
+                "value": self.grafana_password
+            }
+        )
         d["cluster_config"] = self.cluster_config.to_dict()
         return d
 
@@ -484,6 +537,7 @@ class Config:
                      grafana_port=d["grafana_port"],
                      management_system_port=d["management_system_port"],
                      cadvisor_port=d["cadvisor_port"],
+                     pgadmin_port=d["pgadmin_port"],
                      prometheus_port=d["prometheus_port"],
                      node_exporter_pid_file=d["node_exporter_pid_file"],
                      management_system_pid_file=d["management_system_pid_file"],
@@ -500,7 +554,13 @@ class Config:
                      cluster_config=ClusterConfig.from_dict(d["cluster_config"]),
                      node_exporter_log_file=d["node_exporter_log_file"],
                      allow_registration=d["allow_registration"],
-                     allow_host_shell=d["allow_host_shell"])
+                     allow_host_shell=d["allow_host_shell"],
+                     grafana_username=d["grafana_username"],
+                     grafana_password=d["grafana_password"],
+                     pgadmin_username=d["pgadmin_username"],
+                     pgadmin_password=d["pgadmin_password"])
+        if "id" in d:
+            dto.id = d["id"]
         return dto
 
     @staticmethod
@@ -555,7 +615,14 @@ class Config:
                      cluster_config=ClusterConfig.from_dict(d["cluster_config"]),
                      node_exporter_log_file=d["node_exporter_log_file"],
                      allow_registration=d["allow_registration"],
-                     allow_host_shell=d["allow_host_shell"])
+                     allow_host_shell=d["allow_host_shell"],
+                     pgadmin_port=d["pgadmin_port"],
+                     grafana_username=d["grafana_username"],
+                     grafana_password=d["grafana_password"],
+                     pgadmin_username=d["pgadmin_username"],
+                     pgadmin_password=d["pgadmin_password"])
+        if "id" in d:
+            dto.id = d["id"]
         return dto
 
     def __str__(self) -> str:
@@ -595,7 +662,9 @@ class Config:
                f"default_log_dir: {self.default_log_dir}, " \
                f"cluster_config: {self.cluster_config}," \
                f"node_exporter_log_file: {self.node_exporter_log_file}," \
-               f"allow_registration: {self.allow_registration}, allow_host_shell: {self.allow_host_shell}"
+               f"allow_registration: {self.allow_registration}, allow_host_shell: {self.allow_host_shell}," \
+               f"id:{self.id}, grafana_username: {self.grafana_username}, grafana_password: {self.grafana_password}," \
+               f"pgadmin_username: {self.pgadmin_username}, pgadmin_password: {self.pgadmin_password}"
 
     def to_json_str(self) -> str:
         """
@@ -662,63 +731,7 @@ class Config:
             f.write(json_str)
 
     @staticmethod
-    def set_config_parameters_from_config_file() -> None:
-        """
-        Reads the config file from $CSLE_HOME/config.json and initializes certain config parameters
-
-        :return: None
-        """
-        if constants.CONFIG_FILE.CSLE_HOME_ENV_PARAM in os.environ:
-            csle_home = os.environ[constants.CONFIG_FILE.CSLE_HOME_ENV_PARAM]
-        else:
-            raise Exception(f"The environment parameter {constants.CONFIG_FILE.CSLE_HOME_ENV_PARAM} is not set")
-        config_file_path = f"{csle_home}{constants.COMMANDS.SLASH_DELIM}" \
-                           f"{constants.CONFIG_FILE.CONFIG_FILE_NAME}"
-        try:
-            config = Config.read_config_file()
-            constants.CONFIG_FILE.PARSED_CONFIG = config
-            constants.CSLE_ADMIN.MANAGEMENT_USER = config.management_admin_username_default
-            constants.CSLE_ADMIN.MANAGEMENT_PW = config.management_admin_password_default
-            constants.CSLE_ADMIN.MANAGEMENT_EMAIL = config.management_admin_email_default
-            constants.CSLE_ADMIN.MANAGEMENT_ORGANIZATION = config.management_admin_organization_default
-            constants.CSLE_ADMIN.MANAGEMENT_FIRST_NAME = config.management_admin_first_name_default
-            constants.CSLE_ADMIN.MANAGEMENT_LAST_NAME = config.management_admin_last_name_default
-            constants.CSLE_ADMIN.SSH_USER = config.ssh_admin_username
-            constants.CSLE_ADMIN.SSH_PW = config.ssh_admin_password
-            constants.CSLE_GUEST.MANAGEMENT_USER = config.management_guest_username_default
-            constants.CSLE_GUEST.MANAGEMENT_PW = config.management_guest_password_default
-            constants.CSLE_GUEST.MANAGEMENT_EMAIL = config.management_guest_email_default
-            constants.CSLE_GUEST.MANAGEMENT_ORGANIZATION = config.management_guest_organization_default
-            constants.CSLE_GUEST.MANAGEMENT_FIRST_NAME = config.management_guest_first_name_default
-            constants.CSLE_GUEST.MANAGEMENT_LAST_NAME = config.management_guest_last_name_default
-            constants.AGENT.USER = config.ssh_agent_username
-            constants.AGENT.PW = config.ssh_agent_password
-            constants.METADATA_STORE.USER = config.metastore_user
-            constants.METADATA_STORE.PASSWORD = config.metastore_password
-            constants.METADATA_STORE.HOST = config.metastore_ip
-            constants.METADATA_STORE.DBNAME = config.metastore_database_name
-            constants.COMMANDS.NODE_EXPORTER_PORT = config.node_exporter_port
-            constants.COMMANDS.GRAFANA_PORT = config.grafana_port
-            constants.COMMANDS.MANAGEMENT_SYSTEM_PORT = config.management_system_port
-            constants.COMMANDS.CADVISOR_PORT = config.cadvisor_port
-            constants.COMMANDS.PROMETHEUS_PORT = config.prometheus_port
-            constants.COMMANDS.NODE_EXPORTER_PID_FILE = config.node_exporter_pid_file
-            constants.COMMANDS.MANAGEMENT_SYSTEM_PID_FILE = config.management_system_pid_file
-            constants.COMMANDS.NODE_EXPORTER_LOG_FILE = config.node_exporter_log_file
-            constants.COMMANDS.DOCKER_STATS_MANAGER_OUTFILE = config.docker_stats_manager_outfile
-            constants.COMMANDS.DOCKER_STATS_MANAGER_PIDFILE = config.docker_stats_manager_pidfile
-            constants.COMMANDS.PROMETHEUS_PID_FILE = config.prometheus_pid_file
-            constants.COMMANDS.PROMETHEUS_LOG_FILE = config.prometheus_log_file
-            constants.COMMANDS.PROMETHEUS_CONFIG_FILE = config.prometheus_config_file
-            constants.LOGGING.DEFAULT_LOG_DIR = config.default_log_dir
-            Logger.__call__().get_logger().info(f"Successfully initialized configuration "
-                                                f"from configuration file: {config_file_path}")
-        except Exception as e:
-            Logger.__call__().get_logger().info(f"Failed to read configuration file from: {config_file_path}. "
-                                                f"Exception: {str(e)}, {repr(e)}")
-
-    @staticmethod
-    def get_current_confg() -> Union["Config", None]:
+    def get_current_config() -> Union["Config", None]:
         """
         :return: The currently parsed config
         """
